@@ -1,5 +1,5 @@
 import random
-from card import Card
+from card_game_analysis.card import Card
 
 
 class Deck:
